"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var path_1 = require("path");
var fs_1 = require("fs");
var dotenv_1 = require("dotenv");
var process_1 = require("process");
var find_1 = require("find");
var escape_string_regexp_1 = __importDefault(require("escape-string-regexp"));
function getDataverseConfig(development) {
    var dataverseConfigPath = path_1.resolve(process.cwd(), "./dataverse.config.js");
    var config;
    if (fs_1.existsSync(dataverseConfigPath)) {
        config = require(dataverseConfigPath);
    }
    else {
        config = {};
    }
    applyDefaultConfiguration(config, !!development);
    return config;
}
exports.default = getDataverseConfig;
function applyDefaultConfiguration(dataverseConfig, development) {
    if (development) {
        applyDefaultEnvironmentVariables(dataverseConfig);
    }
    Object.assign(dataverseConfig, {
        srcPath: dataverseConfig.srcPath || "src",
        portalPath: dataverseConfig.portalPath || "portal",
        assets: dataverseConfig.assets || createDefaultAssets(),
    });
}
function applyDefaultEnvironmentVariables(config) {
    var _a, _b, _c, _d, _e, _f, _g, _h;
    if (!(config.environmentUrl &&
        ((_a = config.credentials) === null || _a === void 0 ? void 0 : _a.clientId) &&
        ((_b = config.credentials) === null || _b === void 0 ? void 0 : _b.clientSecret) &&
        ((_c = config.credentials) === null || _c === void 0 ? void 0 : _c.authority) &&
        ((_d = config.credentials) === null || _d === void 0 ? void 0 : _d.tenantId))) {
        dotenv_1.config();
        Object.assign(config, {
            environmentUrl: config.environmentUrl || getRequiredEnvironmentVariable("URL"),
            credentials: {
                clientId: ((_e = config.credentials) === null || _e === void 0 ? void 0 : _e.clientId) ||
                    getRequiredEnvironmentVariable("CLIENT_ID"),
                clientSecret: ((_f = config.credentials) === null || _f === void 0 ? void 0 : _f.clientSecret) ||
                    getRequiredEnvironmentVariable("CLIENT_SECRET"),
                authority: ((_g = config.credentials) === null || _g === void 0 ? void 0 : _g.authority) ||
                    process.env.AUTHORITY ||
                    "https://login.microsoftonline.com/",
                tenantId: ((_h = config.credentials) === null || _h === void 0 ? void 0 : _h.tenantId) ||
                    getRequiredEnvironmentVariable("TENANT_ID"),
            },
        });
    }
}
function getRequiredEnvironmentVariable(name) {
    var value = process.env[name];
    if (!value) {
        throw new Error("Missing environment variable " + name + ". " +
            "Either add it as an environment variable or assign it a .env file (https://www.npmjs.com/package/dotenv).");
    }
    return value;
}
function createDefaultAssets() {
    var srcDirectory = path_1.resolve(process_1.cwd(), "src");
    var files = fs_1.readdirSync(srcDirectory);
    var assets = {};
    for (var _i = 0, files_1 = files; _i < files_1.length; _i++) {
        var file = files_1[_i];
        var stats = fs_1.lstatSync(srcDirectory + "/" + file);
        if (stats.isFile()) {
            var assetSourceFile = file.replace(/\.[a-z0-9]+$/, "");
            var assetPath = findAsset(assetSourceFile);
            if (assetPath) {
                assets[file] = assetPath;
            }
        }
    }
    return assets;
}
var slash = escape_string_regexp_1.default(path_1.sep);
var regexRoot = "" + escape_string_regexp_1.default(process_1.cwd()) + slash + "portal" + slash;
var regexItem = "[^/\\\\]+";
var regexAssetQueries = [
    "" + regexItem + slash + "basic-forms" + slash,
    "" + regexItem + slash + "advanced-forms" + slash + regexItem + slash + "advanced-form-steps" + slash,
];
function findAsset(name) {
    for (var _i = 0, regexAssetQueries_1 = regexAssetQueries; _i < regexAssetQueries_1.length; _i++) {
        var regexAssetQuery = regexAssetQueries_1[_i];
        var files = find_1.fileSync(new RegExp("^" + regexRoot + regexAssetQuery + name, "i"), process_1.cwd() + "/portal");
        if (files.length > 0) {
            return files[0].replace(new RegExp("^" + regexRoot + "(" + regexAssetQuery + name + ").*$", "i"), "$1");
        }
    }
}
